Saltypie - salt-api wrapper and state return parser.
====================================================

Installation
============

.. code-block:: bash

   pip install saltypie


Examples
========

https://gitlab.com/cathaldallan/saltypie/tree/master/examples


Documentation
=============

https://cathaldallan.gitlab.io/saltypie/